@@ -1215,7 +1215,8 @@ class MindsDBParser(Parser):
                     condition=p.expr)
 
     @_('from_table_aliased COMMA from_table_aliased',
-       'join_tables_implicit COMMA from_table_aliased')
+       'join_tables_implicit COMMA from_table_aliased',
+       'join_tables COMMA from_table_aliased')
     def join_tables_implicit(self, p):
         return Join(left=p[0],
                     right=p[2],
@@ -1282,6 +1283,9 @@ class MindsDBParser(Parser):
        'OUTER JOIN',
        'LEFT OUTER JOIN',
        'FULL OUTER JOIN',
+       'ASOF JOIN',
+       'ASOF LEFT JOIN',
+       'LEFT ASOF JOIN',
        )
     def join_clause(self, p):
         return ' '.join([x for x in p])
